OC.L10N.register(
    "mail",
    {
    "Creating account failed: " : "ការបង្កើត​គណនី​បរាជ័យ",
    "Mail" : "សំបុត្រ",
    "Name" : "ឈ្មោះ",
    "Password" : "ពាក្យសម្ងាត់",
    "None" : "គ្មាន",
    "Save" : "រក្សាទុក",
    "Connect" : "ភ្ជាប់",
    "Sending …" : "កំពុង​ផ្ញើរ...",
    "Send" : "ផ្ញើ",
    "Select" : "Select",
    "Delete" : "លុប",
    "Important" : "សំខាន់",
    "Favorites" : "Favorites",
    "Other" : "ផ្សេងៗ",
    "Settings" : "ការកំណត់",
    "Add folder" : "Add folder",
    "Cancel" : "បោះបង់",
    "Delete folder" : "លុប​ថត",
    "Reply" : "ឆ្លើយតប",
    "General" : "ទូទៅ",
    "User" : "User",
    "Host" : "ម៉ាស៊ីន​ផ្ទុក",
    "Port" : "ច្រក",
    "Search" : "Search",
    "All" : "ទាំងអស់",
    "Drafts" : "ពង្រាង",
    "Inbox" : "ក្នុង​ប្រអប់សារ",
    "Junk" : "ព្រៃ",
    "Sent" : "ផ្ញើ",
    "Trash" : "ធុង​សំរាម"
},
"nplurals=1; plural=0;");
